==> lidia-editor-1.0.14.tgz: package/CONTRIBUTING.md <==
# Contributing to npm-react-typescript-template

First off, thanks for taking the time to contribute! 🎉

The following is a set of guidelines for contributing to this project. These are just guidelines, not rules, so feel free to propose changes to this document in a pull request.

## How Can I Contribute?

### Reporting Bugs

- Ensure the bug was not already reported by searching on GitHub under [Issues](https://github.com/helgastogova/npm-react-typescript-template/issues).
- If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/helgastogova/npm-react-typescript-template/issues/new). Be sure to include a title and clear description, as much relevant information as possible, and a code sample or an executable test case demonstrating the expected behavior that is not occurring.

### Suggesting Enhancements

- Open a new issue and clearly outline your suggestion, explaining the context and reason behind it. If possible, also discuss potential solutions or implementations, or the steps needed to introduce the change.

### Pull Requests

- Fork the repository and create your branch from `master`.
- Make sure your code lints.
- Submit the pull request!

## Code Style

Please adhere to the existing coding style. We use Prettier and ESLint, so if possible, enable their respective plugins in your editor to get real-time feedback. The rules are automatically enforced with a pre-commit hook.

## License

By contributing, you agree that your contributions will be licensed under its MIT License.

## Need help?

If you need help with anything, feel free to open an issue. We're here to help you!

==> lidia-editor-1.0.18.tgz: package/CONTRIBUTING.md <==
# Contributing to lidia-editor

First off, thanks for taking the time to contribute! 🎉

The following is a set of guidelines for contributing to this project. These are just guidelines, not rules, so feel free to propose changes to this document in a pull request.

## How Can I Contribute?

### Reporting Bugs

- Ensure the bug was not already reported by searching on GitHub under [Issues](https://github.com/codechappie/lidia-editor/issues).
- If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/codechappie/lidia-editor/issues/new). Be sure to include a title and clear description, as much relevant information as possible, and a code sample or an executable test case demonstrating the expected behavior that is not occurring.

### Suggesting Enhancements

- Open a new issue and clearly outline your suggestion, explaining the context and reason behind it. If possible, also discuss potential solutions or implementations, or the steps needed to introduce the change.

### Pull Requests

- Fork the repository and create your branch from `master`.
- Make sure your code lints.
- Submit the pull request!

## Code Style

Please adhere to the existing coding style. We use Prettier and ESLint, so if possible, enable their respective plugins in your editor to get real-time feedback. The rules are automatically enforced with a pre-commit hook.

## License

By contributing, you agree that your contributions will be licensed under its MIT License.

## Need help?

If you need help with anything, feel free to open an issue. We're here to help you!
